@@ -1,6 +1,4 @@
-
-GRAFANA_DATASOURCE = \
-"""
+GRAFANA_DATASOURCE = """
 apiVersion: 1
 
 datasources:
@@ -14,8 +12,7 @@ datasources:
     editable: true
 """
 
-GRAFANA_DASHBOARD = \
-"""
+GRAFANA_DASHBOARD = """
 apiVersion: 1
 
 providers:
