@@ -1,5 +1,4 @@
-HYBRID_DASHBOARD = \
-r"""
+HYBRID_DASHBOARD = r"""
 {
   "annotations": {
     "list": [
@@ -797,4 +796,4 @@ r"""
   "uid": "dJazsVd4z",
   "version": 4
 }
-"""
\ No newline at end of file
+"""
